@@ -145,10 +145,10 @@ ges_asset_cache_put (GESAsset * asset, GTask *task);
 G_GNUC_INTERNAL gboolean
 ges_asset_cache_set_loaded(GType extractable_type, const gchar * id, GError *error);
 
-GST_EXPORT GESAsset*
+GES_API GESAsset*
 ges_asset_cache_lookup(GType extractable_type, const gchar * id);
 
-GST_EXPORT gboolean
+GES_API gboolean
 ges_asset_try_proxy (GESAsset *asset, const gchar *new_id);
 
 G_GNUC_INTERNAL gboolean
@@ -385,6 +385,7 @@ G_GNUC_INTERNAL GESVideoTestSource * ges_video_test_source_new (void);
  *              GESTimelineElement                  *
  ****************************************************/
 G_GNUC_INTERNAL gdouble ges_timeline_element_get_media_duration_factor(GESTimelineElement *self);
+G_GNUC_INTERNAL GESTimelineElement * ges_timeline_element_get_copied_from (GESTimelineElement *self);
 
 /******************************
  *  GESMultiFile internal API *
